@@ -5,11 +5,11 @@ use warnings;
 
 # ABSTRACT: A wrapper around the regular data processed by DataFlow
 
-our $VERSION = '1.112100';    # VERSION
+our $VERSION = '1.121260';    # VERSION
 
 use Moose;
 use Moose::Autobox;
-use MooseX::ChainedAccessors;
+use MooseX::Attribute::Chained;
 
 use namespace::autoclean;
 
@@ -84,7 +84,7 @@ DataFlow::Item - A wrapper around the regular data processed by DataFlow
 
 =head1 VERSION
 
-version 1.112100
+version 1.121260
 
 =head1 SYNOPSIS
 
@@ -182,10 +182,8 @@ the same terms as the Perl 5 programming language system itself.
 
 =head1 BUGS AND LIMITATIONS
 
-No bugs have been reported.
-
-Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
+You can make new bug reports, and view existing ones, through the
+web interface at L<http://rt.cpan.org>.
 
 =head1 DISCLAIMER OF WARRANTY
 
