@@ -5,7 +5,7 @@ use warnings;
 
 # ABSTRACT: A data processor class
 
-our $VERSION = '1.112100';    # VERSION
+our $VERSION = '1.121260';    # VERSION
 
 use Moose;
 with 'DataFlow::Role::Processor';
@@ -37,11 +37,12 @@ has 'deref' => (
 );
 
 has 'policy' => (
-    'is'      => 'ro',
-    'isa'     => 'ProcPolicy',
-    'coerce'  => 1,
-    'lazy'    => 1,
-    'builder' => '_policy',
+    'is'       => 'ro',
+    'isa'      => 'ProcPolicy',
+    'coerce'   => 1,
+    'lazy'     => 1,
+    'builder'  => '_policy',
+    'init_arg' => 'policy',
 );
 
 has 'p' => (
@@ -112,7 +113,7 @@ DataFlow::Proc - A data processor class
 
 =head1 VERSION
 
-version 1.112100
+version 1.121260
 
 =head1 SYNOPSIS
 
@@ -239,10 +240,8 @@ the same terms as the Perl 5 programming language system itself.
 
 =head1 BUGS AND LIMITATIONS
 
-No bugs have been reported.
-
-Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
+You can make new bug reports, and view existing ones, through the
+web interface at L<http://rt.cpan.org>.
 
 =head1 DISCLAIMER OF WARRANTY
 
