@@ -5,10 +5,9 @@ use warnings;
 
 # ABSTRACT: A role that defines how to use proc-handlers
 
-our $VERSION = '1.112100';    # VERSION
+our $VERSION = '1.121260';    # VERSION
 
 use Moose::Role;
-use Moose::Autobox;
 
 use namespace::autoclean;
 use Scalar::Util 'reftype';
@@ -82,12 +81,16 @@ sub _handle_scalar_ref {
 
 sub _handle_array_ref {
     my ( $p, $item ) = @_;
-    return $item->map( sub { _run_p( $p, $_ ) } );
+
+    #use Data::Dumper; warn 'handle_array_ref :: item = ' . Dumper($item);
+    my @r = map { _run_p( $p, $_ ) } @{$item};
+    return [@r];
 }
 
 sub _handle_hash_ref {
     my ( $p, $item ) = @_;
-    return { @{ $item->keys->map( sub { $_ => _run_p( $p, $item->{$_} ) } ) } };
+    my %r = map { $_ => _run_p( $p, $item->{$_} ) } keys %{$item};
+    return {%r};
 }
 
 sub _handle_code_ref {
@@ -109,7 +112,7 @@ DataFlow::Role::ProcPolicy - A role that defines how to use proc-handlers
 
 =head1 VERSION
 
-version 1.112100
+version 1.121260
 
 =head2 apply P ITEM
 
@@ -140,10 +143,8 @@ the same terms as the Perl 5 programming language system itself.
 
 =head1 BUGS AND LIMITATIONS
 
-No bugs have been reported.
-
-Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
+You can make new bug reports, and view existing ones, through the
+web interface at L<http://rt.cpan.org>.
 
 =head1 DISCLAIMER OF WARRANTY
 
