@@ -5,7 +5,7 @@ use warnings;
 
 # ABSTRACT: Type definitions for DataFlow
 
-our $VERSION = '1.112100';    # VERSION
+our $VERSION = '1.121260';    # VERSION
 
 use MooseX::Types -declare => [
     qw(Processor ProcessorList WrappedProcList ProcessorSub ProcPolicy),
@@ -193,7 +193,7 @@ DataFlow::Types - Type definitions for DataFlow
 
 =head1 VERSION
 
-version 1.112100
+version 1.121260
 
 =head1 SYNOPSIS
 
@@ -443,10 +443,8 @@ the same terms as the Perl 5 programming language system itself.
 
 =head1 BUGS AND LIMITATIONS
 
-No bugs have been reported.
-
-Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
+You can make new bug reports, and view existing ones, through the
+web interface at L<http://rt.cpan.org>.
 
 =head1 DISCLAIMER OF WARRANTY
 
